summaryrefslogtreecommitdiffstats
path: root/qtsharp/src/examples/tutorials/t2.cs
diff options
context:
space:
mode:
Diffstat (limited to 'qtsharp/src/examples/tutorials/t2.cs')
-rw-r--r--qtsharp/src/examples/tutorials/t2.cs4
1 files changed, 2 insertions, 2 deletions
diff --git a/qtsharp/src/examples/tutorials/t2.cs b/qtsharp/src/examples/tutorials/t2.cs
index 5dbe07d1..3692e8f4 100644
--- a/qtsharp/src/examples/tutorials/t2.cs
+++ b/qtsharp/src/examples/tutorials/t2.cs
@@ -18,8 +18,8 @@ public class Example {
quit.SetFont (new TQFont ("Times", 18, TQFont.Weight.Bold));
// In C++, TQFont::Bold is sufficient
- TQObject.Connect ( quit, QtSupport.TQT_SIGNAL ("clicked()"), a, QtSupport.TQT_SLOT ("Quit()") );
- // TQT_SIGNAL and TQT_SLOT are static functions of QtSupport
+ TQObject.Connect ( quit, QtSupport.TQ_SIGNAL ("clicked()"), a, QtSupport.TQ_SLOT ("Quit()") );
+ // TQ_SIGNAL and TQ_SLOT are static functions of QtSupport
a.SetMainWidget (quit);
quit.Show ();